@@ -65,7 +65,7 @@ pub fn solve(input: &mut Input) -> Result<String, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     test_part_one!("abcdefgh" => "abcdffaa".to_string());
 
