@@ -27,7 +27,7 @@ pub fn solve(input: &mut Input) -> Result<usize, String> {
 
 #[test]
 fn test() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let real_input = include_str!("day04_input.txt");
     test_part_one!(real_input => 325);
