@@ -59,7 +59,7 @@ pub fn solve(input: &mut Input) -> Result<u32, String> {
 
 #[test]
 fn test_part1() {
-    use crate::{test_part_one, test_part_one_error, test_part_two};
+    use crate::input::{test_part_one, test_part_one_error, test_part_two};
     let real_input = include_str!("day06_input.txt");
     test_part_one!(real_input => 12841);
     test_part_two!(real_input => 8038);
